/***************************************************************
*                                                              *
*            Copyright (c) 1990 - 1996 Gordian Inc.            *
*                                                              *
*       Author: Nathaniel Z. Rutman                            *
*       Module: np_filter.c      (from lpr_filter)             *
*       Created: 6/7/96                                        *
*       Abstract:                                              *
*         This is the main program for an RTEL command line    *
*         peripheral filter.  It will coordinate all           *
*         activity required to send an input file to a         *
*         service on an ETS terminal server.                   *
*                                                              *
*       Input:                                                 *
*         The file to be sent is specified on the command      *
*         line.  If no file is specified, STDIN is used.       *
*                                                              *
*       Output:                                                *
*         If everything works perfectly, the requested file is *
*         send to the specified peripheral.  If something      *
*         fails, an error message will be written to the queue *
*         status file.                                         *
*                                                              *
*       Disclaimer:                                            *
*         The information in this software is subject to       *
*         change without notice and should not be construed    *
*         as a commitment by the developers of this software   *
*         package.                                             *
*                                                              *
***************************************************************/

#include <udpinc.h>

main(argc,argv)
    int argc;
unsigned char* argv[];
{
    udp_data usr;
    int stat,trycnt=0;
    
    rtel_zero(&usr, sizeof(udp_data));
    
    signal_stuff();
    
    /* creates the status file only if it doesn't currently exist */
    if (open_jobstat_fil()) {
	errs(&usr, RTEL_CNTOPNJOB, "np_filter:main");
	wrerr(&usr,TERMINAL);
	goto ERR;
    }
    
    /* defaults */
    usr.fdp = stdin;  /* default file */
    usr.copies = 1;  /* for lpr, only print out 1 copy */
    /* get username */
    if(fgets(usr.usernam, MAXLEN, popen("logname","r"))) {  /* better way? */
	dprintf(dbgbuf, "user name -- %s", usr.usernam);
	dbgout(dbgbuf);
    }
    else
	strcpy(usr.usernam, "No username available");   
    
    /* parse command line */
    if ((stat = np_parse(argc,argv,&usr)) != OK) goto ERR;
    
    if (usr.tcp_socket == 0) {
	errs(&usr, RTEL_BADSOCK, "np_filter:main - need non-zero socket");
	goto ERR;
    }
    
    /* if there's a filename, open the file */
    if (usr.fname[0]) {
	if ((usr.fdp = fopen(usr.fname, "r")) == NULL) {
	    errs(&usr, RTEL_BADOPN, "np_filter:main - bad filename");
	    goto ERR;
	}
    }
    
    /* make the connection */
    if(usr.flags & OPT_VERBOSE) {
	fprintf(stderr, "Connection initiated\n");
    }
    while ((stat = npconn_socket(&usr)) < OK) {     
	dbgout("np_filter: main - no connect");
	if(stat == FATAL_ERR)  /* don't retry */
	    goto ERR;
	if((usr.flags & OPT_NORETRY)
	   || (trycnt > NO_PROGRESS)) {	/* or (trycnt > ABORT_JOB) ? */
	    errs(&usr, RTEL_NOCONN, "np_filter:main - no connect");
	    goto ERR;
	}
	trycnt++;
	sleep(1);
    }
    if(usr.flags & OPT_VERBOSE) {
	fprintf(stderr, "Connection successful\n");
    }
    
    /* send the banner */
    if (usr.flags & OPT_BANNER) 
	createbanner(&usr);
    
    /* send the file */
    if ((stat = process_file(&usr)) != OK) 
	goto ERR;
    
    /* all done */
    if(usr.flags & OPT_VERBOSE) {
	fprintf(stderr, "\nTransfer complete\n");
    }
    
    dbgout("Exiting np_filter with good status");
    exit (0);    
    
    ERR:
    dbgout("Exiting from np_filter with bad status");
    wrerr(&usr, TERMINAL);
    exit(-1);
}


