/******************************************************************************
*                                                                             *
*            Copyright (c) 1990 - 1996 Gordian Inc.                           *
*                                                                             *
*       Author: Nathan Rutman                                                 *
*       Module: npconnect.c  (from talk.c)                                    *
*       Created: 6/10/96                                                      *
*       Abstract:                                                             *
*         This routine will establish a  TCP connection to a specific port    *
*         on a server and return the network channel to be used for reads and *
*         writes.                                                             *
*                                                                             *
*       Input:                                                                *
*         The udp_data structure (host, tcp.socket)                           *
*                                                                             *
*       Output:                                                               *
*         The tcp_fd field in udp_data will return the network channel        *
*                                                                             *
*       Disclaimer:                                                           *
*         The information in this software is subject to                      *
*         change without notice and should not be construed                   *
*         as a commitment by the developers of this software                  *
*         package.                                                            *
*                                                                             *
******************************************************************************/


/*  Edit History:
*/

#include <udpinc.h>

int npconn_socket(users)
udp_data *users;
{
    struct hostent     *hdata, *gethostbyname();
    struct sockaddr_in insock;

    int ret_stat;
    
    /* Create a local socket. */

    if((users->tcp_fd = socket(AF_INET, SOCK_STREAM, TCP)) < 0){
	dbgout("conn_socket: Unable to create network socket.\r\n");
	return(PROC_ERR);
    }

    /* Get the host IP address. */

    hdata = gethostbyname(users->host);
    if(!hdata){
	dbgout("conn_socket: Unable to find host in host table.\r\n");
	errs(users, RTEL_HSTNTFND, "conn_socket:host missing from host table");
	return(FATAL_ERR);
    }

    /* Set up the IP address parameters and try to connect to the server. */
    
    insock.sin_family = AF_INET;
    insock.sin_port = htons(users->tcp_socket);
    rtel_copy(*hdata->h_addr_list, &insock.sin_addr, hdata->h_length);
    
    if ((ret_stat=connect(users->tcp_fd, (struct sockaddr *) &insock, sizeof(insock))) < 0) {
	dprintf(dbgbuf,"conn_socket: Unable to connect to network socket, errno -- %d\r\n", errno);
	dbgout(dbgbuf);
	return(PROC_ERR);
    }

    /* Looks like everything worked.  The network socket is returned
       in users->tcp_fd.  Return a good return status. */

    return(OK);
}
